@@ -429,9 +429,12 @@ setup_property_notify (GsdWacomDevice *device)
 	XISetMask (evmask.mask, XI_PropertyEvent);
 
 	dpy = GDK_DISPLAY_XDISPLAY (gdk_display_get_default ());
-	XISelectEvents (dpy, DefaultRootWindow (dpy), &evmask, 1);
 
+	gdk_error_trap_push ();
+	XISelectEvents (dpy, DefaultRootWindow (dpy), &evmask, 1);
 	g_free (evmask.mask);
+	if (gdk_error_trap_pop ())
+		return TRUE;
 
 	gdk_window_add_filter (NULL,
 			       (GdkFilterFunc) filter_events,
@@ -1485,6 +1488,7 @@ gsd_wacom_device_constructor (GType                     type,
 			device->priv->type = WACOM_TYPE_INVALID;
 			goto end;
 		}
+		libwacom_error_free (&wacom_error);
 	}
 
 	gsd_wacom_device_update_from_db (device, wacom_device, device->priv->path);
